==> ah-formbuilder-1.0.59.tgz: package/es/utils/alertdialog/AlertDialog.js <==
var _jsxFileName = "/home/mirza/code/formbuilder/src/utils/alertdialog/AlertDialog.js";
import React from 'react';
import Button from '@material-ui/core/Button';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogTitle from '@material-ui/core/DialogTitle';
import DialogContentText from '@material-ui/core/DialogContentText';
import { CircularProgress, Typography } from '@material-ui/core';
export default function AlertDialog(props) {
  var open = props.open,
      title = props.title,
      message = props.message,
      primaryLabel = props.primaryLabel,
      secondaryLabel = props.secondaryLabel,
      primaryAction = props.primaryAction,
      secondaryAction = props.secondaryAction,
      primaryActionLoading = props.primaryActionLoading,
      secondaryActionLoading = props.secondaryActionLoading;
  return /*#__PURE__*/React.createElement("div", {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 24,
      columnNumber: 3
    }
  }, /*#__PURE__*/React.createElement(Dialog, {
    open: open,
    onClose: secondaryAction,
    fullWidth: true,
    classes: {
      paper: 'rounded-8'
    },
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 25,
      columnNumber: 4
    }
  }, /*#__PURE__*/React.createElement(DialogTitle, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 33,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    className: "text-14",
    variant: "h6",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 34,
      columnNumber: 6
    }
  }, title || '')), /*#__PURE__*/React.createElement(DialogContent, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 38,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(DialogContentText, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 39,
      columnNumber: 6
    }
  }, message)), /*#__PURE__*/React.createElement(DialogActions, {
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 41,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(Button, {
    disabled: !!secondaryActionLoading,
    onClick: secondaryAction,
    color: "secondary",
    variant: "outlined",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 42,
      columnNumber: 6
    }
  }, !!secondaryActionLoading && /*#__PURE__*/React.createElement(CircularProgress, {
    size: "2.4rem",
    className: "mr-4 rtl:ml-4",
    color: "secondary",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 49,
      columnNumber: 8
    }
  }), secondaryLabel), primaryLabel ? /*#__PURE__*/React.createElement(Button, {
    disabled: !!primaryActionLoading,
    onClick: primaryAction,
    autoFocus: true,
    variant: "contained",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 54,
      columnNumber: 7
    }
  }, !!primaryActionLoading && /*#__PURE__*/React.createElement(CircularProgress, {
    size: "2.4rem",
    className: "mr-4 rtl:ml-4",
    color: "secondary",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 62,
      columnNumber: 9
    }
  }), primaryLabel) : '')));
}

==> ah-formbuilder-1.0.61.tgz: package/es/utils/alertdialog/AlertDialog.js <==
import React from 'react';
import Button from '@material-ui/core/Button';
import Dialog from '@material-ui/core/Dialog';
import DialogActions from '@material-ui/core/DialogActions';
import DialogContent from '@material-ui/core/DialogContent';
import DialogTitle from '@material-ui/core/DialogTitle';
import DialogContentText from '@material-ui/core/DialogContentText';
import { CircularProgress, Typography } from '@material-ui/core';
export default function AlertDialog(props) {
  var open = props.open,
      title = props.title,
      message = props.message,
      primaryLabel = props.primaryLabel,
      secondaryLabel = props.secondaryLabel,
      primaryAction = props.primaryAction,
      secondaryAction = props.secondaryAction,
      primaryActionLoading = props.primaryActionLoading,
      secondaryActionLoading = props.secondaryActionLoading;
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Dialog, {
    open: open,
    onClose: secondaryAction,
    fullWidth: true,
    classes: {
      paper: 'rounded-8'
    }
  }, /*#__PURE__*/React.createElement(DialogTitle, null, /*#__PURE__*/React.createElement(Typography, {
    className: "text-14",
    variant: "h6"
  }, title || '')), /*#__PURE__*/React.createElement(DialogContent, null, /*#__PURE__*/React.createElement(DialogContentText, null, message)), /*#__PURE__*/React.createElement(DialogActions, null, /*#__PURE__*/React.createElement(Button, {
    disabled: !!secondaryActionLoading,
    onClick: secondaryAction,
    color: "secondary",
    variant: "outlined"
  }, !!secondaryActionLoading && /*#__PURE__*/React.createElement(CircularProgress, {
    size: "2.4rem",
    className: "mr-4 rtl:ml-4",
    color: "secondary"
  }), secondaryLabel), primaryLabel ? /*#__PURE__*/React.createElement(Button, {
    disabled: !!primaryActionLoading,
    onClick: primaryAction,
    autoFocus: true,
    variant: "contained"
  }, !!primaryActionLoading && /*#__PURE__*/React.createElement(CircularProgress, {
    size: "2.4rem",
    className: "mr-4 rtl:ml-4",
    color: "secondary"
  }), primaryLabel) : '')));
}
